@@ -61,7 +61,8 @@ xmldb_resolve (BonoboMoniker               *moniker,
 	}
 
 	if (pdb != CORBA_OBJECT_NIL) {
-		Bonobo_ConfigDatabase_addDatabase (db, pdb, "",ev);
+		Bonobo_ConfigDatabase_addDatabase (db, pdb, "",
+		        Bonobo_ConfigDatabase_DEFAULT, ev);
 		
 		bonobo_object_release_unref (pdb, NULL);
 			
@@ -115,7 +116,8 @@ dirdb_resolve (BonoboMoniker               *moniker,
 	}
 
 	if (pdb != CORBA_OBJECT_NIL) {
-		Bonobo_ConfigDatabase_addDatabase (db, pdb, "", ev);
+		Bonobo_ConfigDatabase_addDatabase (db, pdb, "", 
+		        Bonobo_ConfigDatabase_DEFAULT, ev);
 		
 		bonobo_object_release_unref (pdb, NULL);
 		
